#ifndef SCREENSAVERAPP_H
#define SCREENSAVERAPP_H

#include <QGuiApplication>
#include "vmdaemon_interface.h"
#include "Auth.h"
#include <QApplication>

#define SaverApp ScreenSaverApp::instance()
class QLocalSocket;
class IdleWatcher;
class QProcess;
class ScreenSaver;
namespace NSS {
class PowerManager;
class SocketServer;
class LockScreenShortcut;
class LockScreenManager;

class ScreenSaverApp : public QApplication
{
    Q_OBJECT
public:
    explicit ScreenSaverApp(int &argc, char **argv);
    ~ScreenSaverApp();
    static ScreenSaverApp *instance() { return self; }

    PowerManager *powerManager() const;
    bool locked() const;
    void setIdleTime(int secs);
signals:
    void stopped();
    void loggingIn(QLocalSocket *socket);
    void loginFailed(QLocalSocket *socket);
    void loginSucceeded(QLocalSocket *socket);

public slots:
    void slotRequestChanged();
    void slotAuthenticationFinished(const QString &user, bool success);
    void slotHelperFinished(Auth::HelperExitStatus status);
    void slotAuthInfo(const QString &message, Auth::Info info);
    void slotAuthError(const QString &message, Auth::Error error);
    void login(QLocalSocket *socket,
               const QString &user, const QString &password);
    void lockSession();
private:
    void unLock();
    static ScreenSaverApp *self;
    Auth *m_auth { nullptr };
    SocketServer *m_socketServer { nullptr };
    PowerManager *mPowerManager { nullptr };
    QLocalSocket *m_socket { nullptr };
    QString m_passPhrase;
    IdleWatcher *mIdleWatcher;
    QProcess *mLockGreeter;
    int mIdleTime;
    LockScreenShortcut *mShortcut;
    com::vm::daemon *daemonInterface;
    LockScreenManager *mLockScreenManager;
    ScreenSaver *mScreenSaver;
};
}
#endif // SCREENSAVERAPP_H
