#include "idlewatcher.h"
#include <KIdleTime>
#include <QDebug>
#include <QtDBus>

IdleWatcher::IdleWatcher(int secs, QObject *parent):
    QObject(parent),
    mSecs(secs)
{
    connect(KIdleTime::instance(),
            &KIdleTime::resumingFromIdle,
            this,
            &IdleWatcher::onResumingFromIdle);
    connect(KIdleTime::instance(),
            static_cast<void (KIdleTime::*)(int)>(&KIdleTime::timeoutReached),
            this,
            &IdleWatcher::onTimeoutReached);
    setup();
}

IdleWatcher::~IdleWatcher()
{
    KIdleTime::instance()->removeAllIdleTimeouts();
}

void IdleWatcher::reset(int secs)
{
    KIdleTime::instance()->removeAllIdleTimeouts();
    mSecs = secs;
    setup();
}

void IdleWatcher::onResumingFromIdle()
{
    qDebug() << "Somethings happened";
}

void IdleWatcher::onTimeoutReached(int identifier)
{
    mIdentifier = identifier;
    qDebug() << "Timeout Reached, id=" << identifier;
    KIdleTime::instance()->removeIdleTimeout(mIdentifier);
    emit requestLock();
}
void IdleWatcher::removeIdleTimeout()
{
    if(mIdentifier > 0)
        KIdleTime::instance()->removeIdleTimeout(mIdentifier);
}
void IdleWatcher::setup()
{
    KIdleTime::instance()->addIdleTimeout(1000 * mSecs);
}
