#ifndef LOCKSCREENMANAGER_H
#define LOCKSCREENMANAGER_H

#include <QObject>
#include <QDBusInterface>
#include <QScopedPointer>
#include <QTimer>
class QDBusUnixFileDescriptor;
namespace NSS {

class LockScreenProvider : public QObject
{
    Q_OBJECT

public:
    virtual ~LockScreenProvider() {}

    virtual bool isValid() = 0;
    virtual bool inhibit() = 0;
    virtual void release() = 0;

signals:
    void aboutToSleep(bool beforeSleep);
    void lockRequested();
};

class LogindProvider : public LockScreenProvider
{
    Q_OBJECT

public:
    explicit LogindProvider();
    virtual ~LogindProvider();

    bool isValid() override;
    bool inhibit() override;
    void release() override;

private:
    QDBusInterface mInterface;
    QScopedPointer<QDBusUnixFileDescriptor> mFileDescriptor;
};

class ConsoleKit2Provider : public LockScreenProvider
{
    Q_OBJECT

public:
    explicit ConsoleKit2Provider();
    virtual ~ConsoleKit2Provider();

    bool isValid() override;
    bool inhibit() override;
    void release() override;

private:
    QDBusInterface mInterface;
    bool mMethodInhibitPresent;
    QScopedPointer<QDBusUnixFileDescriptor> mFileDescriptor;
};

class LockScreenManager : public QObject
{
    Q_OBJECT
public:
    enum LOCK_STATUS{
        UNLOCKED = 1,
        LOCKED

    };
    explicit LockScreenManager(QObject *parent = nullptr);
    virtual ~LockScreenManager();

    bool startup(bool lockBeforeSleep, int powerAfterLockDelay/*!< ms*/);
    void saveLockStatus(LOCK_STATUS status);
private:
    void inhibit();
private:
    LockScreenProvider *mProvider;
    bool mLockedBeforeSleep;
};
}
#endif
